createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
UnBlindOberonTokenRequest createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
UnBlindOberonTokenRequest createEmptyInstance() => create();